@@ -32,8 +32,8 @@
         
         for(i in 1:M)
           {
-            why   = RESCALE( dof[[i]], prange[1]  ,prange[2] , min(dof[[i]], na.rm = TRUE)  , max(dof[[i]], na.rm = TRUE)  )
-            lines(freqs, why, col=COL[i], lty=2)
+            why   = RPMG::RESCALE( dof[[i]], prange[1]  ,prange[2] , min(dof[[i]], na.rm = TRUE)  , max(dof[[i]], na.rm = TRUE)  )
+            lines(freqs[[i]], why, col=COL[i], lty=2)
           }  
         
         
@@ -49,8 +49,8 @@
           {
             
             w = which(Fv[[i]]>q1)
-            points(freqs[w], amp[[i]][w], col="brown", pch=8)
-########  why   = RESCALE( Fv[[i]], prange[1]  ,  prange[1] + (prange[2]-prange[1])/2 , min(Fv[[i]], na.rm = TRUE)  , max(Fv[[i]], na.rm = TRUE)  )
+            points(freqs[[i]][w], amp[[i]][w], col="brown", pch=8)
+########  why   = RPMG::RESCALE( Fv[[i]], prange[1]  ,  prange[1] + (prange[2]-prange[1])/2 , min(Fv[[i]], na.rm = TRUE)  , max(Fv[[i]], na.rm = TRUE)  )
 ########  lines(freqs, why, col=i, lty=3)
           }  
         
@@ -60,8 +60,8 @@
     
     for(i in 1:M)
       {
-        lines(freqs, amp[[i]], col=COL[i], lty=1)
-        text(freqs[1], amp[[i]][1], i, col=COL[i], pos=2)
+        lines(freqs[[i]], amp[[i]], col=COL[i], lty=1)
+        text(freqs[[i]][1], amp[[i]][1], i, col=COL[i], pos=2)
       }
     if(!is.null(a$stamps))
       {
